==> linuxconf_1.17r5.orig.tar.gz: linuxconf-1.17r5/modapi/modapi.pm <==
/* internal.cc 05/01/1998 22.50.08 */
PUBLIC M_DIALOG_INTERNAL::M_DIALOG_INTERNAL (void);
PUBLIC M_DIALOG_INTERNAL::~M_DIALOG_INTERNAL (void);
/* modapi.cc 09/01/2000 01.27.48 */
PUBLIC M_FIELD_COMBO::M_FIELD_COMBO (FIELD_COMBO *_real,
	 M_FIELD_COMBO *first);
PUBLIC void M_FIELD_COMBO::addopt (const char *str);
PUBLIC void M_FIELD_COMBO::addopt (const char *value,
	 const char *verbose);
PUBLIC M_FIELD_LIST::M_FIELD_LIST (FIELD_LIST *_real,
	 M_FIELD_LIST *first);
PUBLIC void M_FIELD_LIST::addopt (const char *str);
PUBLIC void M_FIELD_LIST::addopt (const char *value,
	 const char *verbose);
PUBLIC M_FIELD_COMBO_MANY::M_FIELD_COMBO_MANY (FIELD_COMBO_MANY *_real,
	 M_FIELD_COMBO_MANY *first);
PUBLIC M_FIELD_ENUM::M_FIELD_ENUM (FIELD_ENUM *_real,
	 M_FIELD_ENUM *first);
PUBLIC void M_FIELD_ENUM::addopt (const char *str);
PUBLIC void M_FIELD_ENUM::addopt (const char *value,
	 const char *verbose);
PUBLIC void M_DIALOG::newf_chk (const char *prompt,
	 char &var,
	 const char *title);
PUBLIC void M_DIALOG::newf_chkm (const char *prompt,
	 char &var,
	 const char *title[]);
PUBLIC void M_DIALOG::newf_chkm_num (const char *prompt,
	 int &var,
	 const int vals[],
	 const char *title[]);
PUBLIC void M_DIALOG::newf_chkm_col (const char *prompt,
	 char &var,
	 const char *title[]);
PUBLIC void M_DIALOG::save (void);
PUBLIC void M_DIALOG::reload (void);
PUBLIC void M_DIALOG::reload (int no);
PUBLIC void M_DIALOG::reload (int start, int end);
PUBLIC void M_DIALOG::restore (void);
PUBLIC void M_DIALOG::set_readonly (void);
PUBLIC void M_DIALOG::set_lastreadonly (void);
PUBLIC void M_DIALOG::last_noempty (void);
PUBLIC int M_DIALOG::was_modified (void);
PUBLIC void M_DIALOG::seticon (const char *_icon);
PUBLIC void M_DIALOG::setbutinfo (int id,
	 const char *title,
	 const char *icon);
PUBLIC void M_DIALOG::html_body (const char *ctl, ...);
PUBLIC void M_DIALOG::html_intro (const char *ctl, ...);
PUBLIC void M_DIALOG::html_top (const char *ctl, ...);
PUBLIC void M_DIALOG::html_end (const char *ctl, ...);
PUBLIC void M_DIALOG::set_alt_title (const char *_title);
PUBLIC void M_DIALOG::setsidetitle (const char *ctl, ...);
PUBLIC M_FIELD_COMBO *M_DIALOG::newf_combo (const char *prompt,
	 SSTRING&str);
PUBLIC M_FIELD_LIST *M_DIALOG::newf_list (const char *prompt,
	 SSTRING&str);
PUBLIC M_FIELD_ENUM *M_DIALOG::newf_enum (const char *prompt,
	 int &sel);
PUBLIC M_FIELD_COMBO_MANY *M_DIALOG::newf_combo_many (const char *prompt,
	 SSTRING&str);
PUBLIC int M_DIALOG::remove_del (int no);
PUBLIC void M_DIALOG::newf_str (const char *prompt,
	 char *str,
	 int maxsiz);
PUBLIC void M_DIALOG::newf_str (const char *prompt, SSTRING&str);
PUBLIC void M_DIALOG::newf_str (const char *prompt,
	 SSTRING&str,
	 int width);
PUBLIC void M_DIALOG::newf_pass (const char *prompt, SSTRING&str);
PUBLIC void M_DIALOG::newf_num (const char *prompt, int &val);
PUBLIC void M_DIALOG::newf_hexnum (const char *prompt, int &val);
PUBLIC void M_DIALOG::newf_octnum (const char *prompt, int &val);
PUBLIC void M_DIALOG::newf_dbl (const char *prompt,
	 double &val,
	 int nbdecimals);
PUBLIC void M_DIALOG::newf_slider (const char *prompt,
	 int &val,
	 int minval,
	 int maxval);
PUBLIC void M_DIALOG::newf_gauge (const char *prompt,
	 int &val,
	 int range);
PUBLIC void M_DIALOG::newf_title (const char *pad,
	 int level,
	 const char *prompt,
	 const char *msg);
PUBLIC void M_DIALOG::newf_title (const char *prompt, const char *msg);
PUBLIC void M_DIALOG::newf_head (const char *prompt, const char *msg);
PUBLIC void M_DIALOG_RECORDS::newf_head (const char *prompt,
	 const char *msg);
PUBLIC void M_DIALOG::new_menuline (const char *icon,
	 const char *prompt1,
	 const char *prompt2,
	 bool may_select);
PUBLIC void M_DIALOG::new_menuitem (const char *prompt1,
	 const char *prompt2);
PUBLIC void M_DIALOG::set_menuitem (int no,
	 const char *prompt1,
	 const char *prompt2);
PUBLIC void M_DIALOG::new_menuitem (const char *icon,
	 const char *prompt1,
	 const char *prompt2);
PUBLIC void M_DIALOG::new_menuinfo (const char *prompt1,
	 const char *prompt2);
PUBLIC void M_DIALOG::new_menuitem (const char *prompt1,
	 const SSTRING&prompt2);
PUBLIC void M_DIALOG::new_menuitem (const SSTRING&prompt1,
	 const SSTRING&prompt2);
PUBLIC void M_DIALOG::new_menuitems (const char *items[],
	 int item_no);
PUBLIC void M_DIALOG::new_menuitems (const char *opt[]);
PUBLIC const char *M_DIALOG::getmenustr (int choice);
PUBLIC void M_DIALOG::savewhat (const char *help);
PUBLIC void M_DIALOG::delwhat (const char *help);
PUBLIC void M_DIALOG::inswhat (const char *help);
PUBLIC void M_DIALOG::addwhat (const char *help);
PUBLIC void M_DIALOG::setheight_hint (void);
PUBLIC MENU_STATUS M_DIALOG::editmenu (const char *title,
	 const char *prompt,
	 HELP_FILE&helpfile,
	 int &sel,
	 int options);
PUBLIC M_DIALOG::M_DIALOG (void);
PUBLIC M_DIALOG::M_DIALOG (DIALOG *_real);
PUBLIC M_DIALOG::~M_DIALOG (void);
PUBLIC MENU_STATUS M_DIALOG::edit (const char *_title,
	 const char *_intro,
	 HELP_FILE&helpfile,
	 int &nof,
	 int but_options);
PUBLIC void M_DIALOG::show (const char *_title,
	 const char *_intro,
	 HELP_FILE&helpfile,
	 int &nof,
	 int but_options);
PUBLIC MENU_STATUS M_DIALOG::edit (const char *_title,
	 const char *_intro,
	 HELP_FILE&helpfile);
PUBLIC MENU_STATUS M_DIALOG::edit (const char *_title,
	 const char *_intro,
	 HELP_FILE&helpfile,
	 int &nof);
PUBLIC void M_DIALOG::newf_radio (const char *prompt,
	 char &var,
	 char instance_val,
	 const char *title);
PUBLIC void M_DIALOG::remove_all (void);
PUBLIC int M_DIALOG::getnb (void);
PROTECTED M_DIALOG::M_DIALOG (int);
PUBLIC void M_DIALOG_MENU::setmenu (MENU_CONTEXT ctx);
PUBLIC M_DIALOG_RECORDS::M_DIALOG_RECORDS (void);
PROTECTED M_DIALOG_RECORDS::M_DIALOG_RECORDS (int);
PUBLIC MENU_STATUS M_DIALOG_RECORDS::editmenu (const char *title,
	 const char *prompt,
	 HELP_FILE&helpfile,
	 int &sel,
	 int options);
PUBLIC void M_DIALOG_RECORDS::setkeyformat (HTML_KEY_TYPE key_type);
PUBLIC M_DIALOG_LISTE::M_DIALOG_LISTE (void);
PUBLIC MENU_STATUS M_DIALOG_LISTE::editmenu (const char *title,
	 const char *prompt,
	 HELP_FILE&helpfile,
	 int &sel,
	 int options);
PUBLIC MENU_STATUS M_DIALOG_MENU::editmenu (const char *title,
	 const char *prompt,
	 HELP_FILE&helpfile,
	 int &sel,
	 int options);
PUBLIC M_DIALOG_MENU::M_DIALOG_MENU (void);
PUBLIC void M_DIALOG::gui_passthrough (int command,
	 const char *args,
	 ...);
PUBLIC void M_DIALOG::newline (void);
PUBLIC void M_DIALOG::newf_info (const char *prompt, const char *str);
PUBLIC void M_DIALOG::newf_sheet (const char *prompt,
	 const char *titles[],
	 SSTRINGS&tb);
PUBLIC void M_DIALOG::addhelp (HELP_FILE&help, const char *title);
PUBLIC void M_DIALOG::settype (DIALOG_TYPE type);
PUBLIC void M_DIALOG_TEXTBOX::newf_text (const char *prompt,
	 const char *buftab);
PUBLIC void M_DIALOG_TEXTBOX::newf_text (const char *prompt,
	 const SSTRINGS&tb);
PUBLIC void M_DIALOG::newf_textarea (const char *prompt,
	 SSTRING&text,
	 int width,
	 int height);
PUBLIC void M_DIALOG::setcontext (const char *s);
PUBLIC void M_DIALOG::remove_last (int cut);
PUBLIC void M_DIALOG::hide (void);

==> linuxconf_1.26r4.orig.tar.gz: linuxconf-1.26r4/modapi/modapi.pm <==
/* internal.cc 27/09/2000 13.36.24 */
PUBLIC M_DIALOG_INTERNAL::M_DIALOG_INTERNAL (void);
PUBLIC M_DIALOG_INTERNAL::~M_DIALOG_INTERNAL (void);
/* modapi.cc 29/08/2001 22.58.20 */
PUBLIC M_FIELD_COMBO::M_FIELD_COMBO (FIELD_COMBO *_real,
	 M_FIELD_COMBO *first);
PUBLIC void M_FIELD_COMBO::addopt (const char *str);
PUBLIC void M_FIELD_COMBO::addopt (const char *value,
	 const char *verbose);
PUBLIC void M_FIELD_COMBO::addopts (const SSTRINGS&lst);
PUBLIC void M_FIELD_COMBO::addopts (const SSTRING_KEYS&lst);
PUBLIC M_FIELD_LIST::M_FIELD_LIST (FIELD_LIST *_real,
	 M_FIELD_LIST *first);
PUBLIC void M_FIELD_LIST::addopt (const char *str);
PUBLIC void M_FIELD_LIST::addopt (const char *value,
	 const char *verbose);
PUBLIC void M_FIELD_LIST::addopt (const char *value,
	 const char *shown,
	 const char *verbose);
PUBLIC M_FIELD_COMBO_MANY::M_FIELD_COMBO_MANY (FIELD_COMBO_MANY *_real,
	 M_FIELD_COMBO_MANY *first);
PUBLIC M_FIELD_ENUM::M_FIELD_ENUM (FIELD_ENUM *_real,
	 M_FIELD_ENUM *first);
PUBLIC void M_FIELD_ENUM::addopt (const char *str);
PUBLIC void M_FIELD_ENUM::addopt (const char *value,
	 const char *verbose);
PUBLIC M_FIELD_CLIST::M_FIELD_CLIST (FIELD_CLIST *_real,
	 M_FIELD_CLIST *first);
PUBLIC void M_FIELD_CLIST::setheader (const char *s);
PUBLIC void M_FIELD_CLIST::addrecord (const char *s);
PUBLIC void M_FIELD_CLIST::addrecordf (const char *s, ...);
PUBLIC void M_FIELD_CLIST::insrecord (int pos, const char *s);
PUBLIC void M_FIELD_CLIST::setrecord (int no, const char *s);
PUBLIC void M_FIELD_CLIST::setrecordf (int pos, const char *s, ...);
PUBLIC int M_FIELD_CLIST::getnb (void)const;
PUBLIC const char *M_FIELD_CLIST::getline (int no)const;
PUBLIC void M_FIELD_CLIST::setcursor (int pos, bool focus);
PUBLIC void M_DIALOG::newf_chk (const char *prompt,
	 char &var,
	 const char *title);
PUBLIC void M_DIALOG::newf_chkm (const char *prompt,
	 char &var,
	 const char *title[]);
PUBLIC void M_DIALOG::newf_chkm_num (const char *prompt,
	 int &var,
	 const int vals[],
	 const char *title[]);
PUBLIC void M_DIALOG::newf_chkm_num (const char *prompt,
	 int &var,
	 const int defvar,
	 const int vals[],
	 const char *title[]);
PUBLIC void M_DIALOG::newf_chkm_col (const char *prompt,
	 char &var,
	 const char *title[]);
PUBLIC void M_DIALOG::save (void);
PUBLIC void M_DIALOG::reload (void);
PUBLIC void M_DIALOG::reload (int no);
PUBLIC void M_DIALOG::reload (int start, int end);
PUBLIC void M_DIALOG::restore (void);
PUBLIC void M_DIALOG::set_readonly (void);
PUBLIC void M_DIALOG::set_lastreadonly (void);
PUBLIC void M_DIALOG::last_noempty (void);
PUBLIC int M_DIALOG::was_modified (void);
PUBLIC void M_DIALOG::seticon (const char *_icon);
PUBLIC void M_DIALOG::setbutinfo (int id,
	 const char *title,
	 const char *icon);
PUBLIC void M_DIALOG::html_body (const char *ctl, ...);
PUBLIC void M_DIALOG::html_intro (const char *ctl, ...);
PUBLIC void M_DIALOG::html_top (const char *ctl, ...);
PUBLIC void M_DIALOG::html_end (const char *ctl, ...);
PUBLIC void M_DIALOG::set_alt_title (const char *_title);
PUBLIC void M_DIALOG::setsidetitle (const char *ctl, ...);
PUBLIC M_FIELD_COMBO *M_DIALOG::newf_combo (const char *prompt,
	 SSTRING&str);
PUBLIC M_FIELD_COMBO *M_DIALOG::newf_combo (const char *prompt,
	 SSTRING&str,
	 int maxsiz);
PUBLIC M_FIELD_LIST *M_DIALOG::newf_list (const char *prompt,
	 SSTRING&str);
PUBLIC M_FIELD_ENUM *M_DIALOG::newf_enum (const char *prompt,
	 int &sel);
PUBLIC M_FIELD_COMBO_MANY *M_DIALOG::newf_combo_many (const char *prompt,
	 SSTRING&str);
PUBLIC M_FIELD_CLIST *M_DIALOG::newf_clist (const char *prompt,
	 int nbvisible,
	 PRIVATE_MESSAGE&msg,
	 int &sel);
PUBLIC int M_DIALOG::remove_del (int no);
PUBLIC void M_DIALOG::newf_str (const char *prompt,
	 char *str,
	 int maxsiz);
PUBLIC void M_DIALOG::newf_str (const char *prompt, SSTRING&str);
PUBLIC void M_DIALOG::newf_str (const char *prompt,
	 SSTRING&str,
	 int width);
PUBLIC void M_DIALOG::newf_pass (const char *prompt, SSTRING&str);
PUBLIC void M_DIALOG::newf_num (const char *prompt, int &val);
PUBLIC void M_DIALOG::newf_hexnum (const char *prompt, int &val);
PUBLIC void M_DIALOG::newf_octnum (const char *prompt, int &val);
PUBLIC void M_DIALOG::newf_dbl (const char *prompt,
	 double &val,
	 int nbdecimals);
PUBLIC void M_DIALOG::newf_slider (const char *prompt,
	 int &val,
	 int minval,
	 int maxval);
PUBLIC void M_DIALOG::newf_gauge (const char *prompt,
	 int &val,
	 int range);
PUBLIC void M_DIALOG::newf_title (const char *pad,
	 int level,
	 const char *prompt,
	 const char *msg);
PUBLIC void M_DIALOG::newf_title (const char *prompt, const char *msg);
PUBLIC void M_DIALOG::newf_head (const char *prompt, const char *msg);
PUBLIC void M_DIALOG_RECORDS::newf_head (const char *prompt,
	 const char *msg);
PUBLIC void M_DIALOG::new_menuline (const char *icon,
	 const char *prompt1,
	 const char *prompt2,
	 bool may_select);
PUBLIC void M_DIALOG::new_menuitem (const char *prompt1,
	 const char *prompt2);
PUBLIC void M_DIALOG::set_menuitem (int no,
	 const char *prompt1,
	 const char *prompt2);
PUBLIC void M_DIALOG::new_menuitem (const char *icon,
	 const char *prompt1,
	 const char *prompt2);
PUBLIC void M_DIALOG::new_menuinfo (const char *prompt1,
	 const char *prompt2);
PUBLIC void M_DIALOG::new_menuitem (const char *prompt1,
	 const SSTRING&prompt2);
PUBLIC void M_DIALOG::new_menuitem (const SSTRING&prompt1,
	 const SSTRING&prompt2);
PUBLIC void M_DIALOG::new_menuitems (const char *items[],
	 int item_no);
PUBLIC void M_DIALOG::new_menuitems (const char *opt[]);
PUBLIC const char *M_DIALOG::getmenustr (int choice);
PUBLIC void M_DIALOG::savewhat (const char *help);
PUBLIC void M_DIALOG::delwhat (const char *help);
PUBLIC void M_DIALOG::inswhat (const char *help);
PUBLIC void M_DIALOG::addwhat (const char *help);
PUBLIC void M_DIALOG::setheight_hint (void);
PUBLIC MENU_STATUS M_DIALOG::editmenu (const char *title,
	 const char *prompt,
	 HELP_FILE&helpfile,
	 int &sel,
	 int options);
PUBLIC M_DIALOG::M_DIALOG (void);
PUBLIC M_DIALOG::M_DIALOG (DIALOG *_real);
PUBLIC M_DIALOG::~M_DIALOG (void);
PUBLIC MENU_STATUS M_DIALOG::edit (const char *_title,
	 const char *_intro,
	 HELP_FILE&helpfile,
	 int &nof,
	 int but_options);
PUBLIC void M_DIALOG::show (const char *_title,
	 const char *_intro,
	 HELP_FILE&helpfile,
	 int &nof,
	 int but_options);
PUBLIC MENU_STATUS M_DIALOG::edit (const char *_title,
	 const char *_intro,
	 HELP_FILE&helpfile);
PUBLIC MENU_STATUS M_DIALOG::edit (const char *_title,
	 const char *_intro,
	 HELP_FILE&helpfile,
	 int &nof);
PUBLIC void M_DIALOG::newf_radio (const char *prompt,
	 char &var,
	 char instance_val,
	 const char *title);
PUBLIC void M_DIALOG::remove_all (void);
PUBLIC int M_DIALOG::getnb (void);
PROTECTED M_DIALOG::M_DIALOG (int);
PUBLIC void M_DIALOG_MENU::setmenu (MENU_CONTEXT ctx);
PUBLIC M_DIALOG_RECORDS::M_DIALOG_RECORDS (void);
PROTECTED M_DIALOG_RECORDS::M_DIALOG_RECORDS (int);
PUBLIC MENU_STATUS M_DIALOG_RECORDS::editmenu (const char *title,
	 const char *prompt,
	 HELP_FILE&helpfile,
	 int &sel,
	 int options);
PUBLIC void M_DIALOG_RECORDS::setkeyformat (HTML_KEY_TYPE key_type);
PUBLIC M_DIALOG_LISTE::M_DIALOG_LISTE (void);
PUBLIC MENU_STATUS M_DIALOG_LISTE::editmenu (const char *title,
	 const char *prompt,
	 HELP_FILE&helpfile,
	 int &sel,
	 int options);
PUBLIC void M_DIALOG_LISTE::set_menuitem (int no,
	 const char *p1,
	 const char *p2);
PUBLIC MENU_STATUS M_DIALOG_MENU::editmenu (const char *title,
	 const char *prompt,
	 HELP_FILE&helpfile,
	 int &sel,
	 int options);
PUBLIC M_DIALOG_MENU::M_DIALOG_MENU (void);
PUBLIC M_DIALOG_MENUPOPUP::M_DIALOG_MENUPOPUP (void);
PUBLIC MENU_STATUS M_DIALOG_MENUPOPUP::editmenu (const char *title,
	 int &sel);
PUBLIC void M_DIALOG::gui_passthrough (int command,
	 const char *args,
	 ...);
PUBLIC void M_DIALOG::newline (void);
PUBLIC void M_DIALOG::gui_label (const char *ctl, ...);
PUBLIC void M_DIALOG::gui_end (void);
PUBLIC void M_DIALOG::gui_group (const char *title);
PUBLIC void M_DIALOG::gui_form (void);
PUBLIC void M_DIALOG::gui_dispolast (GUI_H_DISPO dispoh,
	 int nbcellh,
	 GUI_V_DISPO dispov,
	 int nbcellv);
PUBLIC void M_DIALOG::newf_info (const char *prompt, const char *str);
PUBLIC void M_DIALOG::newf_sheet (const char *prompt,
	 const char *titles[],
	 SSTRINGS&tb);
PUBLIC void M_DIALOG::addhelp (HELP_FILE&help, const char *title);
PUBLIC void M_DIALOG::settype (DIALOG_TYPE type);
PUBLIC void M_DIALOG_TEXTBOX::newf_text (const char *prompt,
	 const char *buftab);
PUBLIC void M_DIALOG_TEXTBOX::newf_text (const char *prompt,
	 const SSTRINGS&tb);
PUBLIC void M_DIALOG::newf_textarea (const char *prompt,
	 SSTRING&text,
	 int width,
	 int height);
PUBLIC void M_DIALOG::setcontext (const char *s);
PUBLIC void M_DIALOG::remove_last (int cut);
PUBLIC void M_DIALOG::hide (void);
PUBLIC void M_DIALOG::waitfor (const char *msg);
PUBLIC void M_DIALOG::waitfor (PRIVATE_MESSAGE&msg);
PUBLIC void M_DIALOG::waitfortimer (const char *id);
PUBLIC void M_DIALOG::waitfortimer (PRIVATE_MESSAGE&msg);
PUBLIC void M_DIALOG::set_button_on_side (void);
PUBLIC void M_DIALOG::set_registry_id (const char *id);
PUBLIC void M_DIALOG::set_selected_button (int button);
PUBLIC void M_DIALOG::set_registry_key (const char *key);
PUBLIC const char *M_DIALOG::setguiname (char tmp[200]);
PUBLIC M_FIELD_BUTTON_TEXT::M_FIELD_BUTTON_TEXT (FIELD_BUTTON_TEXT *_real,
	 M_FIELD_BUTTON_TEXT *first);
PUBLIC M_FIELD_BUTTON_ICON::M_FIELD_BUTTON_ICON (FIELD_BUTTON_ICON *_real,
	 M_FIELD_BUTTON_ICON *first);
PUBLIC M_FIELD_BUTTON_TEXT *M_DIALOG::new_button (const char *str,
	 const char *help,
	 PRIVATE_MESSAGE&msg,
	 bool enter_action);
PUBLIC M_FIELD_BUTTON_TEXT *M_DIALOG::new_button (const char *str,
	 const char *help,
	 PRIVATE_MESSAGE&msg);
PUBLIC M_FIELD_BUTTON_ICON *M_DIALOG::new_button_icon (const char *icon,
	 const char *help,
	 PRIVATE_MESSAGE&msg);
PUBLIC void M_FIELD_BUTTON_TEXT::settext (const char *text);
PUBLIC void M_FIELD_BUTTON_ICON::settext (const char *icon);
PUBLIC FIELD_CHECK_MULTI *M_DIALOG::newf_chkm_str (const char *prompt,
	 int &var,
	 SSTRING&bufstr,
	 const int vals[],
	 const char *options[]);
PUBLIC void M_DIALOG::set_helpdia (PRIVATE_MESSAGE&msg);
PUBLIC void M_DIALOG::set_formparms (const char *parms, ...);
PUBLIC void M_DIALOG::set_guiparms (const char *parms, ...);
PUBLIC void M_DIALOG::request_dump (void);
PUBLIC void M_DIALOG::new_inputgrid (int x,
	 int y,
	 int cellwidth,
	 int cellheight,
	 int nbcellh,
	 int nbcellv,
	 PRIVATE_MESSAGE&msg);
PUBLIC void M_DIALOG::auto_newline (bool mode);
PUBLIC void M_DIALOG::set_nextfield (int no);
PUBLIC void M_DIALOG::setoffset (int offset);
PUBLIC int M_DIALOG::getoffset (void);
PUBLIC void M_DIALOG::newf_ipnum (const char *prompt, SSTRING&ip);
